@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017 Osimis, Belgium
+ * Copyright (C) 2017-2018 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -21,10 +21,12 @@
 
 #pragma once
 
-#include "../Resources/Orthanc/Core/MultiThreading/BagOfTasks.h"
+#include <Core/MultiThreading/BagOfTasks.h>
+#include <Core/WebServiceParameters.h>
 
 #include <string>
 #include <stdint.h>
+#include <boost/program_options.hpp>
 
 namespace OrthancWSI
 {
@@ -45,5 +47,10 @@ namespace OrthancWSI
     void PrintVersion(const char* path);
 
     void ShowVersionInLog(const char* path);
+
+    void AddRestApiOptions(boost::program_options::options_description& section);
+
+    void SetupRestApi(Orthanc::WebServiceParameters& parameters,
+                      const boost::program_options::variables_map& options);
   }
 }
