@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017 Osimis, Belgium
+ * Copyright (C) 2017-2018 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -25,7 +25,7 @@
 #include "Targets/FolderTarget.h"
 #include "Targets/OrthancTarget.h"
 
-#include "../Resources/Orthanc/Core/OrthancException.h"
+#include <Core/OrthancException.h>
 
 #include <boost/thread.hpp>
 #include <boost/lexical_cast.hpp>
@@ -138,11 +138,6 @@ namespace OrthancWSI
 
   void DicomizerParameters::SetDicomMaxFileSize(unsigned int size)
   {
-    if (size <= 1024)
-    {
-      throw Orthanc::OrthancException(Orthanc::ErrorCode_ParameterOutOfRange);
-    }
-
     maxDicomFileSize_ = size;
   }
 
