@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017 Osimis, Belgium
+ * Copyright (C) 2017-2018 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -22,8 +22,8 @@
 #include "PrecompiledHeadersWSI.h"
 #include "Jpeg2000Writer.h"
 
-#include "../Resources/Orthanc/Core/ChunkedBuffer.h"
-#include "../Resources/Orthanc/Core/OrthancException.h"
+#include <Core/ChunkedBuffer.h>
+#include <Core/OrthancException.h>
 
 #include <openjpeg.h>
 #include <string.h>
@@ -246,7 +246,8 @@ namespace OrthancWSI
 #endif
 
     public:
-      OpenJpegOutput(OpenJpegEncoder& encoder) : cio_(NULL)
+      explicit OpenJpegOutput(OpenJpegEncoder& encoder) :
+        cio_(NULL)
       {
 #if ORTHANC_OPENJPEG_MAJOR_VERSION == 1
         cio_ = opj_cio_open(reinterpret_cast<opj_common_ptr>(encoder.GetObject()), NULL, 0);
