@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017 Osimis, Belgium
+ * Copyright (C) 2017-2018 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -22,9 +22,9 @@
 #include "../PrecompiledHeadersWSI.h"
 #include "HierarchicalTiffWriter.h"
 
-#include "../../Resources/Orthanc/Core/Logging.h"
-#include "../../Resources/Orthanc/Core/OrthancException.h"
-#include "../../Resources/Orthanc/Core/TemporaryFile.h"
+#include <Core/Logging.h>
+#include <Core/OrthancException.h>
+#include <Core/TemporaryFile.h>
 
 namespace OrthancWSI
 {
@@ -386,6 +386,8 @@ namespace OrthancWSI
                                                  unsigned int tileHeight) :
     PyramidWriterBase(pixelFormat, compression, tileWidth, tileHeight),
     currentLevel_(0),
+    nextX_(0),
+    nextY_(0),
     isFirst_(true)
   {
     tiff_ = TIFFOpen(path.c_str(), "w");
