@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017 Osimis, Belgium
+ * Copyright (C) 2017-2018 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -24,12 +24,12 @@
 #include "DicomPyramidCache.h"
 #include "../Framework/Jpeg2000Reader.h"
 
-#include "../Resources/Orthanc/Core/Images/ImageProcessing.h"
-#include "../Resources/Orthanc/Core/Images/PngWriter.h"
-#include "../Resources/Orthanc/Core/MultiThreading/Semaphore.h"
-#include "../Resources/Orthanc/Core/OrthancException.h"
-#include "../Resources/Orthanc/Plugins/Samples/Common/OrthancPluginCppWrapper.h"
-#include "../Resources/Orthanc/Plugins/Samples/Common/OrthancPluginConnection.h"
+#include <Core/Images/ImageProcessing.h>
+#include <Core/Images/PngWriter.h>
+#include <Core/MultiThreading/Semaphore.h>
+#include <Core/OrthancException.h>
+#include <Plugins/Samples/Common/OrthancPluginCppWrapper.h>
+#include <Plugins/Samples/Common/OrthancPluginConnection.h>
 
 #include <EmbeddedResources.h>
 
@@ -322,7 +322,7 @@ extern "C"
     transcoderSemaphore_.reset(new Orthanc::Semaphore(threads));
 
     char info[1024];
-    sprintf(info, "The whole-slide imaging plugin will use at most %d threads to transcode the tiles", threads);
+    sprintf(info, "The whole-slide imaging plugin will use at most %u threads to transcode the tiles", threads);
     OrthancPluginLogWarning(context_, info);
 
     OrthancPluginSetDescription(context, "Provides a Web viewer of whole-slide microscopic images within Orthanc.");
